@@ -6,9 +6,9 @@ use base qw/
     DBIx::Class::Schema::Loader::DBI::MSSQL
 /;
 use Carp::Clan qw/^DBIx::Class/;
-use Class::C3;
+use mro 'c3';
 
-our $VERSION = '0.07001';
+our $VERSION = '0.07003';
 
 =head1 NAME
 
