@@ -7,9 +7,9 @@ use base qw/
     DBIx::Class::Schema::Loader::DBI
 /;
 use Carp::Clan qw/^DBIx::Class/;
-use Class::C3;
+use mro 'c3';
 
-our $VERSION = '0.07001';
+our $VERSION = '0.07003';
 
 =head1 NAME
 
@@ -121,6 +121,33 @@ sub _table_uniq_info {
     return \@uniqs;
 }
 
+sub _table_comment {
+    my ( $self, $table ) = @_;
+     my ($table_comment) = $self->schema->storage->dbh->selectrow_array(
+        q{
+            SELECT comments FROM all_tab_comments
+            WHERE owner = ? 
+              AND table_name = ?
+              AND table_type = 'TABLE'
+        }, undef, $self->db_schema, $self->_uc($table)
+    );
+
+    return $table_comment
+}
+
+sub _column_comment {
+    my ( $self, $table, $column_number, $column_name ) = @_;
+    my ($column_comment) = $self->schema->storage->dbh->selectrow_array(
+        q{
+            SELECT comments FROM all_col_comments
+            WHERE owner = ? 
+              AND table_name = ?
+              AND column_name = ?
+        }, undef, $self->db_schema, $self->_uc( $table ), $self->_uc( $column_name )
+    );
+    return $column_comment
+}
+
 sub _table_pk_info {
     my ($self, $table) = (shift, shift);
 
@@ -166,7 +193,7 @@ AND upper(trigger_type) LIKE '%BEFORE EACH ROW%' AND lower(triggering_event) LIK
         $result->{$col_name}{is_auto_increment} = 1;
 
         if (my ($seq_schema, $seq_name) = $trigger_body =~ /(?:\."?(\w+)"?)?"?(\w+)"?\.nextval/i) {
-            $seq_schema = $self->_lc($seq_schema) || $self->db_schema;
+            $seq_schema = $self->_lc($seq_schema || $self->db_schema);
             $seq_name   = $self->_lc($seq_name);
 
             $result->{$col_name}{sequence} = ($self->qualify_objects ? ($seq_schema . '.') : '') . $seq_name;
